# Copyright (C) 2022  NASK PIB
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.


from stylo_metrix.metrics.en.grammatical_forms import grammatical_forms_group
from stylo_metrix.metrics.en.syntactic_en import syntactic_group
from stylo_metrix.metrics.en.lexical_en import lexical_group
original_group = grammatical_forms_group \
                 + syntactic_group \
                 + lexical_group
